/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dirent.h>
#include <app_preference.h>
#include "$(appName).h"
#include "data.h"

#define IMAGES_PATH "images/samples"

static struct data_info {
	Eina_List *list;
} s_info = {
	.list = NULL
};

/**
 * @brief Function initialize the list of all available images paths.
 * This functions searches for the images within application's resource directory
 * (./res/images/samples). Only the files with .png extension are accepted.
 */
void data_initialize(void)
{
	char buf[PATH_MAX] = {0, };
	DIR *dir_h = NULL;
	struct dirent *dir_content = NULL;
	char *p_res_path;
	char *ext;

	p_res_path = app_get_resource_path();
	if (!p_res_path) {
		dlog_print(DLOG_ERROR, LOG_TAG, "app_get_resource_path() failed.");
		return;
	}

	snprintf(buf, sizeof(buf), "%s"IMAGES_PATH, p_res_path);

	dir_h = opendir(buf);
	if (!dir_h) {
		dlog_print(DLOG_ERROR, LOG_TAG, "opendir() failed.");
		free(p_res_path);
		return;
	}

	while ((dir_content = readdir(dir_h)) != NULL) {
		ext = strchr(dir_content->d_name, '.');

		if (!strncmp(ext, ".png", strlen(ext)) &&
			strlen(ext) == strlen(".png")) {
			snprintf(buf, sizeof(buf), "%s"IMAGES_PATH"/%s", p_res_path, dir_content->d_name);
			s_info.list = eina_list_append(s_info.list, strdup(buf));
		}
	}

	closedir(dir_h);
	free(p_res_path);
}

/**
 * @brief Function destroys the list of all available images paths.
 */
void data_finalize(void)
{
	char *str = NULL;

	if (!s_info.list)
		return;

	EINA_LIST_FREE(s_info.list, str)
		free(str);

	eina_list_free(s_info.list);
}

/**
 * @brief Function gets the list of all available images paths.
 * @return Function returns the list of all the images paths found in designated directory.
 * List is NULL when there is no images.
 */
Eina_List *data_get_paths(void)
{
	return s_info.list;
}
